@@ -28,6 +28,12 @@ me.default <- function (sim, obs, na.rm=TRUE, ...){
   
 me.matrix <- function (sim, obs, na.rm=TRUE, ...){
 
+  # Checking that 'sim' and 'obs' have the same dimensions
+  if ( all.equal(dim(sim), dim(obs)) != TRUE )
+    stop( paste("Invalid argument: dim(sim) != dim(obs) ( [", 
+          paste(dim(sim), collapse=" "), "] != [", 
+          paste(dim(obs), collapse=" "), "] )", sep="") )
+
    me <- colMeans( sim - obs, na.rm= na.rm)  
    
    return(me)
